@@ -22,22 +22,22 @@ struct LIBREMIDI_EXPORT port_information
   // PipeWire: unused
   // WinMM: unused
   // WinUWP: unused
-  client_handle client;
+  client_handle client = static_cast<client_handle>(-1);
 
   // ALSA Raw: { uint16_t card, device, sub, padding; }
   // ALSA Seq: { uint32_t client, uint32_t port; }
-  // CoreMIDI: MidiObjectRef
+  // CoreMIDI: MidiObjectRef's kMIDIPropertyUniqueID (uint32_t)
   // WebMIDI: unused
   // JACK: jack_port_id_t
   // PipeWire: port.id
   // WinMM: unset, identified by port_name
   // WinUWP: unused
-  port_handle port;
+  port_handle port = static_cast<port_handle>(-1);
 
-  std::string manufacturer;
-  std::string device_name;
-  std::string port_name;
-  std::string display_name;
+  std::string manufacturer{};
+  std::string device_name{};
+  std::string port_name{};
+  std::string display_name{};
 
   bool operator==(const port_information& other) const noexcept = default;
   std::strong_ordering operator<=>(const port_information& other) const noexcept = default;
@@ -61,10 +61,10 @@ struct observer_configuration
   midi_error_callback on_error{};
   midi_warning_callback on_warning{};
 
-  input_port_callback input_added;
-  input_port_callback input_removed;
-  output_port_callback output_added;
-  output_port_callback output_removed;
+  input_port_callback input_added{};
+  input_port_callback input_removed{};
+  output_port_callback output_added{};
+  output_port_callback output_removed{};
 
   // Observe hardware ports
   uint32_t track_hardware : 1 = true;
