@@ -12,6 +12,7 @@
 #include <ossia/dataflow/graph_node.hpp>
 #include <ossia/dataflow/port.hpp>
 #include <ossia/detail/algorithms.hpp>
+#include <ossia/detail/disable_fpe.hpp>
 #include <ossia/detail/flat_set.hpp>
 #include <ossia/detail/ptr_set.hpp>
 #include <ossia/editor/scenario/time_value.hpp>
@@ -412,6 +413,8 @@ struct OSSIA_EXPORT graph_util
 
   static void init_node(graph_node& n, execution_state& e)
   {
+    disable_fpe();
+
     // Clear the outputs of the node
     for_each_outlet(n, [&](auto& port) { init_outlet(port, e); });
 
@@ -704,9 +707,11 @@ struct OSSIA_EXPORT graph_base : graph_interface
 {
   graph_base() noexcept
   {
+#if !defined(OSSIA_FREESTANDING)
     m_nodes.reserve(1024);
     m_node_list.reserve(1024);
     m_edges.reserve(1024);
+#endif
   }
   [[nodiscard]] tcb::span<ossia::graph_node* const>
   get_nodes() const noexcept final override
@@ -877,7 +882,11 @@ struct OSSIA_EXPORT graph_base : graph_interface
 
   node_map m_nodes;
   edge_map m_edges;
+#if defined(OSSIA_FREESTANDING)
+  ossia::small_vector<ossia::graph_node*, 16> m_node_list;
+#else
   ossia::small_vector<ossia::graph_node*, 1024> m_node_list;
+#endif
 
   graph_t m_graph;
 
