@@ -373,7 +373,9 @@ void oscquery_mirror_asio_protocol::process_raw_osc_data(
 
 void oscquery_mirror_asio_protocol::start_http()
 {
-  m_http->worker = std::make_shared<boost::asio::io_service::work>(m_ctx->context);
+  m_http->worker = std::make_shared<
+      boost::asio::executor_work_guard<boost::asio::io_context::executor_type>>(
+      m_ctx->context.get_executor());
 }
 
 void oscquery_mirror_asio_protocol::start_websockets()
@@ -448,7 +450,7 @@ void oscquery_mirror_asio_protocol::init()
   start_websockets();
   start_osc();
 
-  http_send_message("/?HOST_INFO");
+  http_send_message("/?HOST_INFO=1");
 }
 
 void oscquery_mirror_asio_protocol::request_add_node(
