@@ -135,7 +135,9 @@ namespace string_view
     //           = delete;
     // #endif
 
-    constexpr basic_string_view(const charT *str)
+    QUICKCPPLIB_TEMPLATE(class T)
+    QUICKCPPLIB_TREQUIRES(QUICKCPPLIB_TPRED(std::is_pointer<T>::value && std::is_convertible<T, const_pointer>::value))  // exclude array to pointer
+    constexpr basic_string_view(T str)
         : ptr_(str)
         , len_(traits::length(str))
     {
@@ -147,6 +149,13 @@ namespace string_view
     {
     }
 
+    template<size_t N>
+    constexpr basic_string_view(const charT (&str)[N])
+        : ptr_(str)
+        , len_(N - 1)
+    {
+    }
+
     // iterators
     constexpr const_iterator begin() const noexcept { return ptr_; }
     constexpr const_iterator cbegin() const noexcept { return ptr_; }
