@@ -16,7 +16,8 @@ class SCORE_LIB_BASE_EXPORT QGraphicsIntSlider final
     , public QGraphicsSliderBase<QGraphicsIntSlider>
 {
   W_OBJECT(QGraphicsIntSlider)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(60)
+  friend struct DefaultControlImpl;
   friend struct DefaultGraphicsSliderImpl;
   friend struct QGraphicsSliderBase<QGraphicsIntSlider>;
   int m_value{}, m_execValue{};
@@ -24,9 +25,10 @@ class SCORE_LIB_BASE_EXPORT QGraphicsIntSlider final
   bool m_hasExec{};
 
 public:
-  int min{}, max{};
+  int min{}, max{}, init{};
 
   explicit QGraphicsIntSlider(QGraphicsItem* parent);
+  ~QGraphicsIntSlider();
 
   double from01(double v) const noexcept;
   double unmap(double v) const noexcept;
@@ -35,7 +37,7 @@ public:
   void setValue(int v);
   void setExecutionValue(int v);
   void resetExecution();
-  void setRange(int min, int max);
+  void setRange(int min, int max, int init);
   int value() const;
 
   bool moving = false;
