@@ -165,7 +165,9 @@ struct GfxRenderer<Node_T> final : score::gfx::GenericNodeRenderer
     const auto& mesh = renderer.defaultTriangle();
     this->defaultMeshInit(renderer, mesh, res);
     this->processUBOInit(renderer);
-    this->m_material.init(renderer, this->node.input, this->m_samplers);
+    // Not needed here as we do not have a GPU pass:
+    // this->m_material.init(renderer, this->node.input, this->m_samplers);
+
     std::tie(this->m_vertexS, this->m_fragmentS)
         = score::gfx::makeShaders(renderer.state, generic_texgen_vs, generic_texgen_fs);
 
@@ -315,20 +317,7 @@ struct GfxNode<Node_T> final
   {
     this->instance = id;
 
-    using texture_inputs = avnd::texture_input_introspection<Node_T>;
-    using texture_outputs = avnd::texture_output_introspection<Node_T>;
-
-    // FIXME incorrect if we have other ports before, e.g. a float part followed by an image port
-    for(std::size_t i = 0; i < texture_inputs::size; i++)
-    {
-      this->input.push_back(
-          new score::gfx::Port{this, {}, score::gfx::Types::Image, {}});
-    }
-    for(std::size_t i = 0; i < texture_outputs::size; i++)
-    {
-      this->output.push_back(
-          new score::gfx::Port{this, {}, score::gfx::Types::Image, {}});
-    }
+    initGfxPorts<Node_T>(this, this->input, this->output);
   }
 
   score::gfx::NodeRenderer*
