@@ -216,9 +216,8 @@ public:
     if(cst.empty())
       return [](const QString& p) { return true; };
 
-    return [rexp = std::make_shared<RE2>(cst)](const QString& p) {
-      return RE2::FullMatch(p.toStdString(), *rexp);
-    };
+    return [rexp = std::make_shared<RE2>(re2::StringPiece(cst.data(), cst.size()))](
+               const QString& p) { return RE2::FullMatch(p.toStdString(), *rexp); };
   }
 
   static std::vector<int> filter_constraints(
@@ -344,7 +343,7 @@ public:
           {
             // All the pixels are in the group
             gp.pixels.reserve(matrix.pixels.size());
-            for(int i = 0; i < matrix.pixels.size(); i++)
+            for(std::size_t i = 0; i < matrix.pixels.size(); i++)
               gp.pixels.push_back(i);
           }
         }
