@@ -29,6 +29,7 @@ struct PWM
 {
   int32_t chip{};
   int32_t channel{};
+  int32_t polarity{};
 };
 struct ADC
 {
@@ -53,9 +54,9 @@ using Type = ossia::variant<GPIO, PWM, ADC, DAC, HID, Custom>;
 
 struct Port
 {
-  Type control;
-  QString name;
-  QString path;
+  Type control{};
+  QString name{};
+  QString path{};
 };
 
 }
